@@ -1,5 +1,7 @@
 #!/usr/bin/env python3
 
+import json
+
 def is_identical(fpath_1: str, fpath_2: str) -> bool:
     file_contents = []
     for i, fpath in enumerate([fpath_1, fpath_2]):
@@ -16,3 +18,9 @@ def is_identical(fpath_1: str, fpath_2: str) -> bool:
     if len(file_contents) == 2:
         return file_contents[0] == file_contents[1]
     return False
+
+
+def load_json(fpath: str) -> dict:
+    with open(fpath, "r") as f:
+        data = json.load(f)
+    return data
\ No newline at end of file
